<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="会议名称" prop="meetingName">
        <el-input v-model="queryParams.meetingName" placeholder="请输入会议名称" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="会议地点" prop="roomId">
        <el-select v-model="queryParams.roomId" placeholder="会议地点" clearable>
          <el-option v-for="dict in meetingRoomList" :key="dict.id" :label="dict.name"
            :value="dict.id" />
        </el-select>
      </el-form-item>
      <el-form-item label="会议开始" prop="startTime">
        <el-date-picker v-model="queryParams.startTime" style="width: 250px" value-format="yyyy-MM-dd HH:mm"
          type="daterange" range-separator="-" start-placeholder="开始日期" end-placeholder="结束日期"
          :default-time="['00:00:00', '23:59:59']" />
      </el-form-item>
      <el-form-item label="会议结束" prop="endTime">
        <el-date-picker v-model="queryParams.endTime" style="width: 250px" value-format="yyyy-MM-dd HH:mm"
          type="daterange" range-separator="-" start-placeholder="开始日期" end-placeholder="结束日期"
          :default-time="['00:00:00', '23:59:59']" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
        v-hasPermi="['meeting:reserveList:create']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" icon="el-icon-download" size="mini" @click="handleExport" :loading="exportLoading"
        v-hasPermi="['meeting:reserveList:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="postList">
      <el-table-column label="序号" type="index" width="50"align="center"/>
      <el-table-column label="会议名称" align="center" prop="meetingName" />
      <el-table-column label="会议地点" align="center" prop="roomName" />
      <el-table-column label="会议开始时间" align="center" prop="startTime" min-width="150"/>
      <el-table-column label="会议结束时间" align="center" prop="endTime" min-width="150"/>
      <el-table-column label="申请人" align="center" prop="applyEmployeeName" />
      <el-table-column label="申请部门" align="center" prop="depName" />
      <el-table-column label="参会人数" align="center" prop="number" />
      <el-table-column label="状态" align="center" prop="statusDesc"/>
      <el-table-column label="创建时间" align="center" prop="createTime" width="150">
      <template v-slot="scope">
            <span>{{ parseTime(scope.row.createTime) }}</span>
          </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="180">
        <template v-slot="scope">
          <el-button v-if="scope.row.statusDesc=='未开始'" size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
          v-hasPermi="['meeting:reserveList:update']">修改</el-button>
          <el-button v-if="scope.row.statusDesc=='未开始'" size="mini" type="text" icon="el-icon-cancel" @click="handleCancel(scope.row)"
          v-hasPermi="['meeting:reserveList:cancel']">取消</el-button>
          <el-button v-if="scope.row.statusDesc=='进行中'" size="mini" type="text" icon="el-icon-detail" @click="handleEnd(scope.row)"
          v-hasPermi="['meeting:reserveList:end']">结束</el-button>
          <el-button size="mini" type="text" @click="handleDetail(scope.row)">详情</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNo" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="会议名称" prop="meetingName">
          <el-input v-model="form.meetingName" placeholder="请输入会议名称" />
        </el-form-item>
        <el-form-item label="会议地点" prop="roomId">
          <el-select v-model="form.roomId" placeholder="会议地点" clearable style="width: 100%;">
            <el-option v-for="dict in meetingRoomList" :key="dict.id" :label="dict.name"
              :value="dict.id" />
          </el-select>
        </el-form-item>
        <el-form-item label="开始时间" prop="startTime">
          <el-date-picker v-model="form.startTime" style="width: 100%" type="datetime"
            value-format="yyyy-MM-dd HH:mm" format="yyyy-MM-dd HH:mm" placeholder="选择会议开始时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="结束时间" prop="endTime">
          <el-date-picker v-model="form.endTime" style="width: 100%" type="datetime" value-format="yyyy-MM-dd HH:mm" format="yyyy-MM-dd HH:mm"
            placeholder="选择会议结束时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="申请人" prop="endTime">
          <el-input v-model="form.applyEmployeeName" placeholder="申请人" disabled/>
        </el-form-item>
        <el-form-item label="申请部门" prop="depName">
          <el-input v-model="form.depName" placeholder="申请部门" disabled/>
        </el-form-item>
        <el-form-item label="参会人员" prop="peopleList">
          <el-input type="textarea" v-model="form.peopleList" style="display: none;" />
          <el-button class="button-new-tag" @click="openPS" size="small">+ 添加</el-button>
          <span v-for="(tag, index) in nikeNamelist" :key="index">
            &nbsp;
            <el-tag type="info" closable :disable-transitions="false" @close="handleClose(index)">
              <span class="user-avatar">{{ tag.substring(0, 1) || 'U' }}</span>
              {{ tag }}
            </el-tag>
          </span>

        </el-form-item>

        <el-form-item label="会议内容">
          <el-input v-model="form.meetingContent" type="textarea" placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <!-- 详情对话框 -->
    <el-dialog :title="title" :visible.sync="openDetail" width="800px" append-to-body>
      <div class="widget-wrapper">
        <div class="widget-list" v-loading="loading">
          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">会议名称</div>
            </div>
            <div class="field-component">
              <span :title="form.meetingName">{{ form.meetingName }}</span>
            </div>
          </div>
          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">开始时间</div>
            </div>
            <div class="field-component">
              <span :title="form.startTime">{{ form.startTime }}</span>
            </div>
          </div>
          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">结束时间</div>
            </div>
            <div class="field-component">
              <span :title="form.endTime">{{ form.endTime }}</span>
            </div>
          </div>

          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">申请人</div>
            </div>
            <div class="field-component">
              <span :title="form.applyEmployeeName">{{ form.applyEmployeeName }}</span>
            </div>
          </div>
          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">申请部门</div>
            </div>
            <div class="field-component">
              <span :title="form.depName">{{ form.depName }}</span>
            </div>
          </div>


          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <span class="field-required">*</span>
              <div class="field-name">参会人员</div>
            </div>
            <div class="field-component">
              <span :title="form.participantsName">{{ form.participantsName }}</span>

            </div>
          </div>
          <div class="fx-field x-grid-col-12">
            <div class="field-label">
              <div class="field-name">会议内容</div>
            </div>
            <div class="field-component">
              <span :title="form.meetingContent">{{ form.meetingContent }}</span>
            </div>
          </div>
        </div>
      </div>
    </el-dialog>
    <PeopleSelect ref="peopleSelect" type="multiple" :isCheck="true" :open="peopleOpen" @cancel="peopleOpen = false"
      @submit="submitPeople"></PeopleSelect>
  </div>
</template>

<script>
import { listReserveMeeting, getReserveMeeting, delReserveMeeting,cancelReserveMeeting, addReserveMeeting, updateReserveMeeting, exportReserveMeeting, endReserveMeeting } from "@/api/reserveMeeting";
import { listSimpleMeetings } from "@/api/meeting";
import PeopleSelect from "@/components/PeopleSelect/index.vue";
import { getDictDatas, DICT_TYPE } from '@/utils/dict'

export default {
  name: "SystemReserveMeeting",
  components: {
    PeopleSelect,
  },
  computed: {
    userInfo() {
      return JSON.parse(this.$store.getters.userInfo);
    }
  },
  data() {
    return {
      nikeNamelist: [],
      //是否打开选人组件，默认不打开
      peopleOpen: false,
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 表格数据
      postList: [],
      meetingRoomList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      openDetail: false,
      // 查询参数
      queryParams: {
        pageNo: 1,
        pageSize: 10,
        meetingName: undefined,
        roomId: undefined,
        startTime:[],
        endTime:[],
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        meetingName: [
          { required: true, message: "会议名称不能为空", trigger: "blur" }
        ],
        roomId: [
          { required: true, message: "会议室不能为空", trigger: "blur" }
        ],
        startTime: [
          { required: true, message: "会议开始时间不能为空", trigger: "blur" }
        ],
        endTime: [
          { required: true, message: "会议结束时间不能为空", trigger: "blur" }
        ],
        applyEmployeeName: [
          { required: true, message: "申请人不能为空", trigger: "blur" }
        ],
        depName: [
          { required: true, message: "申请人部门不能为空", trigger: "blur" }
        ],
        peopleList: [
          { required: true, message: '参会人员不能为空', }
        ]
      },
    };
  },
  created() {
    this.getList();
    this.getMeetingList();
  },
  methods: {
     /** 查询会议室列表 */
     getMeetingList() {
      listSimpleMeetings().then(response => {
        this.meetingRoomList = response.data;
      });
    },
   // 关闭标签
   handleClose(index) {
      this.nikeNamelist.splice(index, 1);
      let peopleList = this.form.peopleList.split(',');
      peopleList.splice(index, 1);
      this.form.peopleList = peopleList.join(',');
    },
    //打开选人弹窗
    openPS() {
      this.peopleOpen = true;
    },
    //选择人的确定按钮事件 submitPeople(nikeNamelist)方法传参一个默认接收用户昵称数组   submitPeople(peopleList,nikeNamelist)方法传参两个则是接收用户昵称数组和用户账号数组
    submitPeople(userNamelist, nikeNamelist, userIdList) {
      console.log(userNamelist);
      this.nikeNamelist = nikeNamelist;
      this.form.peopleList = userIdList.join(',');
      this.peopleOpen = false;
    },
    /** 查询列表 */
    getList() {
      this.loading = true;
      listReserveMeeting(this.queryParams).then(response => {
        this.postList = response.data.list;
        this.total = response.data.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        meetingName: undefined,
        roomId: undefined,
        startTime: undefined,
        endTime: undefined,
        applyEmployeeName: this.userInfo.nickname,
        depName: this.userInfo.deptName,
        peopleList: undefined,
        meetingContent: undefined
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNo = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id
      getReserveMeeting(id).then(response => {
        this.form = response.data;
        this.nikeNamelist = response.data.participantsName.split(',');
        this.$set(this.form, 'peopleList', response.data.participants.join(','));
        this.open = true;
        this.title = "修改";
      });
    },
    /** 详情按钮操作 */
    handleDetail(row) {
      this.reset();
      const id = row.id
      getReserveMeeting(id).then(response => {
        this.form = response.data;
        this.openDetail = true;
        this.title = "详情";
      });
    },

    /** 提交按钮 */
    submitForm: function () {
      console.log(this.form);
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.form.participants = this.form.peopleList.split(',');
          if (this.form.id !== undefined) {
            updateReserveMeeting(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addReserveMeeting(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id;
      this.$modal.confirm('是否确认删除编号为"' + ids + '"的数据项?').then(function () {
        return delReserveMeeting(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 取消按钮操作 */
    handleCancel(row) {
      const ids = row.id;
      this.$modal.confirm('是否确认取消"' +  row.meetingName + '"会议?').then(function () {
        return cancelReserveMeeting(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("取消会议成功");
      }).catch(() => { });
    },
    /** 结束按钮操作 */
    handleEnd(row) {
      const ids = row.id;
      this.$modal.confirm('是否确认结束"' +  row.meetingName + '"会议?').then(function () {
        return endReserveMeeting(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("结束会议成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$modal.confirm('是否确认导出所有数据项?').then(() => {
        this.exportLoading = true;
        return exportReserveMeeting(queryParams);
      }).then(response => {
        this.$download.excel(response, '预定信息数据.xls');
        this.exportLoading = false;
      }).catch(() => { });
    }
  }
};
</script>
<style lang="scss" scoped>
.user-avatar {
  width: 22px;
  height: 22px;
  line-height: 19px;
  font-size: 12px;
  background: #46c26f;
  border: 1px solid transparent;
  border-radius: 50%;
  color: #fff;
  display: inline-block;
  overflow: hidden;
  text-align: center;
  vertical-align: middle;
  margin-bottom: 2px;
}

.el-tag+.el-tag {
  margin-left: 10px;
}

.button-new-tag {
  margin-right: 10px;
  height: 30px;
  line-height: 30px;
  padding-top: 0;
  padding-bottom: 0;
}
.widget-wrapper>.widget-list {
  display: flex;
  flex-wrap: wrap;
}

.x-grid-col-6 {
  width: 50%;
}

.x-grid-col-12 {
  width: 100%;
}

.fx-field {
  line-height: 20px;
  padding: 7px 12px 12px;
  position: relative;
}

.fx-field .field-label {
  word-wrap: break-word;
  color: #141e31;
  display: flex;
  font-weight: 600;
  line-height: 20px;
  padding: 5px 0;
  position: relative;
  word-break: break-word;
}

.fx-field .field-label .field-required {
  color: #eb5050;
  margin-left: -6px;
  position: relative;
}

.fx-field .field-label .field-name {
  overflow: hidden;
}

.field-component {
  word-wrap: break-word;
  background: #f5f6f8;
  border-radius: 2px;
  color: #141e31;
  font-size: 14px;
  line-height: 20px;
  min-height: 32px;
  padding: 6px 8px;
  white-space: pre-wrap;
  word-break: break-word;
}

ul {
  padding-left: 0px !important;
}

.el-tag+.el-tag {
  margin-left: 10px;
}
</style>
